Launch an interactive Shiny interface for configuring and generating
camtrapReport outputs from an existing camReport
object.
Arguments
- object
- launch.browser
A logical value (default
TRUE) indicating whether the application is opened in the default web browser.- max_upload_mb
A numeric value (default
2000) giving the maximum file-upload size in megabytes.- ...
Additional arguments passed to
shiny::runApp().
Details
The function starts a Shiny-based graphical user interface for editing report metadata, selecting report sections, defining focus groups, and generating data-status or ecological reports.
The GUI can be used with an existing camReport object and provides an
interactive alternative to configuring reports directly in R.
Examples
if (FALSE) { # interactive()
source_dataset <- system.file(
"external",
"dataset",
package = "camtrapReport"
)
example_dataset <- tempfile("camtrapReport-example-")
dir.create(example_dataset)
invisible(file.copy(
list.files(source_dataset, full.names = TRUE),
example_dataset,
recursive = TRUE
))
cm <- camData(example_dataset)
gui(cm)
unlink(example_dataset, recursive = TRUE, force = TRUE)
}