Get or set field values in a camReport object
info.RdThis function facilitates to extract specific fields (e.g., title, authors, etc.) from a camReport object, or update the value of a field.
Usage
# S4 method for class 'camReport'
info(x, name)
# S4 method for class 'camReport'
info(x, name) <- valueDetails
The camReport object,created by the camData function, contains information extracted from the camera-trap dataset. To control some of these details go to report (e.g., title, subtitle, authors, institute, siteName, description, sampling,...), a user can check their values using the info function or update the value of a certain field.