Returns the names of available report sections/modules. Users can optionally keep only selected sections or exclude selected sections.
Usage
section_names(keep, exclude)
# S4 method for class 'ANY'
section_names(keep, exclude)Returns the names of available report sections/modules. Users can optionally keep only selected sections or exclude selected sections.
section_names(keep, exclude)
# S4 method for class 'ANY'
section_names(keep, exclude)