Test a sub-section object (.textSection class)
testSection.RdIf a sub-section object is created using the reportSection function, it can be tested to see how it looks like in a report.
Details
The object (camReport) is only required if the chunk of R code in the section requires the object!
Examples
tx <- reportSection(name='introduction',title='Introduction',parent=NULL,txt="This is introduction section...",
code = {
# R code:
print(plot(1:10))
})
tx
#> class : .textSection
#> ===========================================================
#> name of the object : introduction
#> title : Introduction
#> parent :
#> is R code included? : TRUE
#> -----------------------------------------------------------
if (FALSE) testSection(tx) # \dontrun{}